@@ -1,14 +1,20 @@
 ##
-## 13 March, 2012
+## December, 2012
 ## D.E. Beaudette
+## J.M. Scovlin
 ## 
 ## prototype functions for extracting component data from local NASIS
 ##
+## requires that named tables are populated in the local NASIS database
 
 get_component_data_from_NASIS_db <- function() {
-	q <- "SELECT dmudesc, coiid, compname, comppct_r, ck.ChoiceName as compkind, majcompflag, localphase, slope_l, slope_r, slope_h, tfact, wei, weg, dc.ChoiceName as drainage_class, elev_l, elev_r, elev_h, aspectccwise, aspectrep, aspectcwise, map_l, map_r, map_h, reannualprecip_l, reannualprecip_r, reannualprecip_h, ffd_l, ffd_r, ffd_h, nirrcapcl, nirrcapscl, irrcapcl, irrcapscl, fa.ChoiceName as frost_action, hydgrp, crc.ChoiceName as corcon, crs.ChoiceName as corsteel, taxclname, txo.ChoiceName as taxorder, txs.ChoiceName as taxsuborder, txgg.ChoiceName as  taxgrtgroup, txsg.ChoiceName as taxsubgrp, txps.ChoiceName as taxpartsize, txpsm.ChoiceName as taxpartsizemod, txact.ChoiceName as taxceactcl, txr.ChoiceName as taxreaction, txtc.ChoiceName as taxtempcl, txmc.ChoiceName as taxmoistscl, txtr.ChoiceName as taxtempregime, txed.ChoiceName as soiltaxedition
-FROM (((((((((((((((((datamapunit 
-	INNER JOIN component ON datamapunit.dmuiid = component.dmuiidref
+	q <- "SELECT dmudesc, coiid, compname, comppct_r, ck.ChoiceName as compkind, majcompflag, localphase, slope_r, tfact, wei, weg, dc.ChoiceName as drainage_class, elev_r, aspectrep, map_r, airtempa_r as maat_r, soiltempa_r as mast_r, reannualprecip_r, ffd_r, nirrcapcl, nirrcapscl, irrcapcl, irrcapscl, fa.ChoiceName as frost_action, hydgrp, crc.ChoiceName as corcon, crs.ChoiceName as corsteel, taxclname, txo.ChoiceName as taxorder, txs.ChoiceName as taxsuborder, txgg.ChoiceName as  taxgrtgroup, txsg.ChoiceName as taxsubgrp, txps.ChoiceName as taxpartsize, txpsm.ChoiceName as taxpartsizemod, txact.ChoiceName as taxceactcl, txr.ChoiceName as taxreaction, txtc.ChoiceName as taxtempcl, txmc.ChoiceName as taxmoistscl, txtr.ChoiceName as taxtempregime, txed.ChoiceName as soiltaxedition, nationalmusym, muname, mk.ChoiceName as mukind, musym, ms.ChoiceName as mustatus, fc.ChoiceLabel as farmlndcl, dmuiid, muiid, repdmu
+FROM (((((((((((((((((((((((
+component 
+INNER JOIN datamapunit ON datamapunit.dmuiid = component.dmuiidref)
+	LEFT OUTER JOIN correlation ON correlation.dmuiidref = datamapunit.dmuiid AND repdmu = 1)
+			LEFT OUTER JOIN mapunit ON mapunit.muiid = correlation.muiidref AND repdmu = 1)
+					LEFT OUTER JOIN lmapunit ON lmapunit.muiidref = mapunit.muiid)
 LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 148) AS dc ON drainagecl = dc.ChoiceValue)
 LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 120) AS fa ON frostact = fa.ChoiceValue)
 LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 103) AS crc ON corcon = crc.ChoiceValue)
@@ -26,7 +32,11 @@ LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomain
 LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 131) AS txmc ON taxmoistscl = txmc.ChoiceValue)
 LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 188) AS txtr ON taxtempregime = txtr.ChoiceValue)
 LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 2030) AS txed ON soiltaxedition = txed.ChoiceValue)
-ORDER BY dmudesc;"
+LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 118) AS mk ON mukind = mk.ChoiceValue)
+LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 138) AS ms ON mustatus = ms.ChoiceValue)
+LEFT OUTER JOIN (SELECT * FROM dbo.MetadataDomainDetail WHERE dbo.MetadataDomainDetail.DomainID = 151) AS fc ON farmlndcl = fc.ChoiceName
+WHERE ms.ChoiceName IS NULL OR ms.Choicename != 'additional'
+ORDER BY dmudesc, coiid, comppct_r DESC;"
 	
 	# setup connection to our pedon database
 	channel <- odbcConnect('nasis_local', uid='NasisSqlRO', pwd='nasisRe@d0n1y')
@@ -93,7 +103,7 @@ fetchNASIS_component_data <- function() {
 	depths(f) <- coiid ~ hzdept_r + hzdepb_r
 	
 	# move site data
-	site(f) <- ~ dmudesc + comppct_r + compname + localphase + compkind + majcompflag
+	site(f) <- ~ slope_r + tfact + wei + weg + drainage_class + elev_r + aspectrep + map_r + maat_r + mast_r + reannualprecip_r + ffd_r + nirrcapcl + nirrcapscl + irrcapcl + irrcapscl + frost_action + hydgrp + corcon + corsteel + taxclname + taxorder + taxsuborder + taxgrtgroup + taxsubgrp + taxpartsize + taxpartsizemod + taxceactcl + taxreaction + taxtempcl + taxmoistscl + taxtempregime + soiltaxedition + dmudesc + compname + comppct_r + compkind + majcompflag + localphase + dmuiid + musym + nationalmusym + muname + mukind + mustatus + farmlndcl + muiid
 	
 	# done, return SPC
 	return(f)
